==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/General/udisks2/translations/udisks2_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>UDisks Plugin Settings</source>
        <translation>UDisks プラグイン設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>音楽 CD 検知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>プレイリストにトラックを自動追加</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>プレイリストからトラックを自動除去</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>着脱可能なデバイスの検知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>プレイリストにファイルを自動追加</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>プレイリストからファイルを自動除去</translation>
    </message>
</context>
<context>
    <name>UDisks2Factory</name>
    <message>
        <location filename="../udisks2factory.cpp" line="30"/>
        <source>UDisks2 Plugin</source>
        <translation>UDisks2 プラグイン</translation>
    </message>
    <message>
        <location filename="../udisks2factory.cpp" line="50"/>
        <source>About UDisks2 Plugin</source>
        <translation>UDisks2 プラグインについて</translation>
    </message>
    <message>
        <location filename="../udisks2factory.cpp" line="51"/>
        <source>Qmmp UDisks2 Plugin</source>
        <translation>QMMP UDisks2 プラグイン</translation>
    </message>
    <message>
        <location filename="../udisks2factory.cpp" line="52"/>
        <source>This plugin provides removable devices detection using UDisks2</source>
        <translation>このプラグインは着脱可能なデバイスの検知を UDisks2 により行ないます</translation>
    </message>
    <message>
        <location filename="../udisks2factory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>UDisks2Plugin</name>
    <message>
        <location filename="../udisks2plugin.cpp" line="130"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>CD &quot;%1&quot; を追加</translation>
    </message>
    <message>
        <location filename="../udisks2plugin.cpp" line="138"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>量目 &quot;%1&quot; を追加</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/General/udisks2/translations/udisks2_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>UDisks Plugin Settings</source>
        <translation>UDisks プラグイン設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>音楽 CD 検知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>プレイリストにトラックを自動追加</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>プレイリストからトラックを自動除去</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>着脱可能なデバイスの検知</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>プレイリストにファイルを自動追加</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>プレイリストからファイルを自動除去</translation>
    </message>
</context>
<context>
    <name>UDisks2Factory</name>
    <message>
        <location filename="../udisks2factory.cpp" line="31"/>
        <source>UDisks2 Plugin</source>
        <translation>UDisks2 プラグイン</translation>
    </message>
    <message>
        <location filename="../udisks2factory.cpp" line="51"/>
        <source>About UDisks2 Plugin</source>
        <translation>UDisks2 プラグインについて</translation>
    </message>
    <message>
        <location filename="../udisks2factory.cpp" line="52"/>
        <source>Qmmp UDisks2 Plugin</source>
        <translation>QMMP UDisks2 プラグイン</translation>
    </message>
    <message>
        <location filename="../udisks2factory.cpp" line="53"/>
        <source>This plugin provides removable devices detection using UDisks2</source>
        <translation>このプラグインは着脱可能なデバイスの検知を UDisks2 により行ないます</translation>
    </message>
    <message>
        <location filename="../udisks2factory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>UDisks2Plugin</name>
    <message>
        <location filename="../udisks2plugin.cpp" line="129"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>CD &quot;%1&quot; を追加</translation>
    </message>
    <message>
        <location filename="../udisks2plugin.cpp" line="137"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>量目 &quot;%1&quot; を追加</translation>
    </message>
</context>
</TS>
